Page 50 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 50

Home

    country is at present as near to anarchy as society can
    approach without dissolution. . . . The authority of the
    King and the nobility is completely subdued, but yet I
    tremble for the constitution."

    As

    the

    and

    of the

    As the success and power of the conspiracy
    increased, so did the atrocities, rising to a new level of
    barbarism during the massacres of September. This
    period began with the rise to power of the Commune
    under Marat.

    success

    spent many years in England studying and practicing
    medicine. While in England, he attempted to stir up the
    people against the government by publishing a pamphlet
    entitled The Chains of Slavery. This effort failed and he

    went to France where he was employed by Danton.
    Marat (a member of the Illurninati) had one consistent
    theme in his writings, the abolition of all class
    distinctions, and the destruction of all who resisted.

    In appearance Marat was an aberration of the human
    race. A dwarf under five feet high, he had a monstrous

    parchment. A burning and haggard eye like a hyena
    added to this, giving him the appearance of something
    out of this world. He usually wore a ragged coat of faded
    green, dingy yellow collar, and a dirty handkerchief
    around his head. "People feared to speak before Marat,"
    says his panegyrist Esquiros; "at the slightest
    contradiction he shows signs of fury, and if one persisted

    his

    the

    says

    45

    The French Revolution

    Morris wrote from France in July of 1789 that "this

    Jean Paul Marat was a native of Switzerland who had

    head, a broken nose, and bronze skin like yellowed